Learn R Programming

htm2txt (version 2.0.0)

browse: Display a plain text in a web page at a certain URL

Description

Display a plain text in a web page at a certain URL

Usage

browse(URL, encoding = "UTF-8")

Arguments

URL

a string containing the URL of a web page.

encoding

a string indicating the encoding method (e.g., "UTF-8", "latin1", "bytes", "unknown", etc.).

Value

None (invisible NULL).

Examples

Run this code
# NOT RUN {
browse("https://CRAN.R-project.org/package=htm2txt")
# }

Run the code above in your browser using DataLab