Learn R Programming

htm2txt (version 2.0.0)

crawltxt: Extract a plain text from a web page at a certain URL

Description

Extract a plain text from a web page at a certain URL

Usage

crawltxt(URL, encoding = "UTF-8")

Arguments

URL

a string indicating the URL of a web page.

encoding

a string indicating the encoding method (e.g., "UTF-8", "latin1", "bytes", "unknown", etc.).

Value

a string containing a plain text converted from the html document at the URL.

Examples

Run this code
# NOT RUN {
text = crawltxt("https://CRAN.R-project.org/package=htm2txt")
# }

Run the code above in your browser using DataLab