powered by
Extract a plain text from a web page at a certain URL
crawltxt(URL, encoding = "UTF-8")
a string indicating the URL of a web page.
a string indicating the encoding method (e.g., "UTF-8", "latin1", "bytes", "unknown", etc.).
a string containing a plain text converted from the html document at the URL.
# NOT RUN { text = crawltxt("https://CRAN.R-project.org/package=htm2txt") # }
Run the code above in your browser using DataLab